#!/bin/bash
# Description: This file is the network performance diagnostic test script for 
# the pNFS regression suite and performance debugging tool chain. It calculates the performance of the link between all the nodes.
# Stage: 0 
# Author: Zainul Abedin (zja) & Swaroop Choudhari (svchoudh)
# Inputs: 
# Detailed Description: 
# Stage0 of the test suite is used to get Experimental setup information. 


export RSH="ssh"
count="0"

if [ $TCP_DUMP -ne 0 ]; then 
    dsh -a -c -- "tcpdump -s 0 -w /tmp/"$SAVE_AS"_multiclient_tcpdata" &
fi


declare -a partitions

let "i=0"

if [ $IOSTAT -ne 0 ]; then 
    if (([ -s "$partition_list" ]) && ([ -r "$partition_list" ]))
	then
	for partition in `cat "$partition_list"`; do
	    partitions[i]=$partition
	    let "i=$i+1"
	done
    fi
    let "i=0"
    for server in `cat $storage_nodes_list`;do
	dsh -m $server -- " iostat -d ${partitions[$i]} -k 5 > "$SAVE_AS"_multiclient_iostatdata " &
	let "i=$i+1"
    done
fi


sleep 2



for f_size in `cat "$filesize_list"`; do
    for r_size in `cat "$recordsize_list"`; do
	if [ $r_size -le $f_size ]; then
	    let "count=1"
	    read_name=""
	    write_name=""
	    while [ "$count" -le "$num_runs" ]; do
		#echo "-l$min_num_clients -u$max_num_clients -+m$client_config_file -C -Rce -i0 -i1 -x -r$r_size -s$f_size -+n > "$PATH_TO_SAVE"multi_client\_report_run"$count""
		iozone -l$min_num_clients -u$max_num_clients -+m "$client_config_file" -C -Rce -i0 -i1 -x -r$r_size -s$f_size -+n > "$PATH_TO_SAVE"multi_client_report_run"$count"
		parse_multiclient_output.sh "$PATH_TO_SAVE"multi_client_report_run"$count" write
		parse_multiclient_output.sh "$PATH_TO_SAVE"multi_client_report_run"$count" read
		read_name="$read_name"' '"$PATH_TO_SAVE"read_multi_client_report_run"$count".txt
		write_name="$write_name"' '"$PATH_TO_SAVE"write_multi_client_report_run"$count".txt
		let "count=$count+1"
	    done
	    echo "$VERSION $FS write $SAVE_AS $min_num_clients $max_num_clients $num_runs $write_name"
	    insert_iozone_multiclient $DB_SERVER $VERSION $FS multi_write \"$SAVE_AS\" $min_num_clients $max_num_clients $f_size $r_size $num_runs $write_name
	    insert_iozone_multiclient $DB_SERVER $VERSION $FS multi_read \"$SAVE_AS\" $min_num_clients $max_num_clients $f_size $r_size $num_runs $read_name
	fi
    done
done


if [ $TCP_DUMP -ne 0 ]; then 
    dsh -a -c -- " killall -s SIGKILL tcpdump"
fi


if [ $IOSTAT -ne 0 ]; then 
    dsh -gstorage_nodes -c -- " killall -s SIGKILL iostat"
fi
